@@ -442,7 +442,7 @@ static void
 phelp_cb (GtkWidget *w, gint tab, gpointer data)
 {
 	GnomeHelpMenuEntry help_entry = { "diskusage_applet",
-					  "index.html#diskusage-applet-prefs" };
+					  "index.html#DISKUSAGE-APPLET-PREFS" };
 	gnome_help_display(NULL, &help_entry);
 }
 
