@@ -451,7 +451,13 @@ save_session(void)
 gint
 save_session_signal(GtkWidget *widget, const char *privcfgpath, const char *globcfgpath)
 {       
+#ifdef HAVE_PANEL_PIXEL_SIZE
+    if(!prop.flat_layout)
+	show_message((gchar *) _("saving prefs...")); 	    
+#else
     show_message((gchar *) _("saving prefs...")); 	    
+#endif
+
     save_session();
 
     /* make sure you return FALSE, otherwise your applet might not
@@ -467,6 +473,15 @@ save_session_signal(GtkWidget *widget, const char *privcfgpath, const char *glob
     globcfgpath = NULL;
 }
 
+static void
+phelp_cb (GtkWidget *w, gint tab, gpointer data)
+{
+        GnomeHelpMenuEntry help_entry = { "mini-commander_applet",
+                                          "index.html#MINI-COMMANDER-PREFS" };
+        gnome_help_display(NULL, &help_entry);
+}
+
+
 void
 properties_box(AppletWidget *applet, gpointer data)
 {
@@ -856,7 +871,7 @@ properties_box(AppletWidget *applet, gpointer data)
 
     gtk_signal_connect(GTK_OBJECT(properties_box),
 		       "help",
-		       GTK_SIGNAL_FUNC(gnome_help_pbox_display),
+		       GTK_SIGNAL_FUNC(phelp_cb),
 		       &help_entry);
     
     gtk_widget_show_all(properties_box);
